scipy.odr.Data
==============

.. currentmodule:: scipy.odr

.. autoclass:: Data

   

   .. HACK
      .. autosummary::
         :toctree:
      
         Data.__init__
         Data.set_meta



   

